@@ -3,11 +3,10 @@
 #include "radiostation.h"
 #include "texteditautoresizer.h"
 
-const QString appVersion = "0.1.0";
+const QString appVersion = "1.0.2";
 
 MainWindow::MainWindow(QWidget *parent) :
-    QMainWindow(parent),
-    ui(new Ui::MainWindow)
+    QMainWindow(parent), ui(new Ui::MainWindow), quitActionPressed(false), hideWhenClosing(false)
 {
     QTime time;
     time.start();
@@ -21,16 +20,20 @@ MainWindow::MainWindow(QWidget *parent) :
 
     qDebug()<<stationsDb.getGenreList();
     qDebug()<<stationsDb.getCountryList();
-    qDebug()<<stationsDb.getFullStationList();
+    qDebug()<<stationsDb.getFullStationList(StationsDB::OrderByName);
 
     loadStationsList();
     populateList(stationsList);
 
     addAction(ui->actionToggleFullscreen);
+    addAction(ui->actionQuit);
+    addAction(ui->actionAddToFavourites);
+    addAction(ui->actionDeleteFromFavourites);
 
     labelBox.setFixedHeight(50);
     labelBox.setAlignment(Qt::AlignCenter);
     infoBox.setWidget(&labelBox);
+
     ui->lyricsWebViewButton->setFont(QFont("Nokia Sans", 12));
 
     nam = new QNetworkAccessManager(this);
@@ -40,7 +43,7 @@ MainWindow::MainWindow(QWidget *parent) :
     connectBluetoothControl();
     new TextEditAutoResizer(ui->cronologyTextEdit);
 
-    //setAttribute(Qt::WA_Maemo5StackedWindow);
+    setAttribute(Qt::WA_Maemo5StackedWindow);
     //setWindowFlags(Qt::Window);
 
     qDebug()<<time.elapsed();
@@ -83,8 +86,11 @@ void MainWindow::getMetaData()
 
             ui->playingLabel->setText(QString(tr("<b>Playing:</b> %1")).arg(title));
 
-            labelBox.setText("Playing '" + extn_metadata_value.toString() + "'");
-            infoBox.show();
+            QString command(QString("dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\"Playing '%1'\"").arg(extn_metadata_value.toString()));
+            system(command.toStdString().c_str());
+            //    labelBox.setText("Playing '" + extn_metadata_value.toString() + "'");
+            //    infoBox.show();
+
 
             QFile file( "/home/user/MyDocs/.documents/InternetRadioPlayerLog.txt" );
             file.open((QIODevice::WriteOnly | QIODevice::Text | QIODevice::Append));
@@ -256,6 +262,7 @@ void MainWindow::setIcons()
 void MainWindow::on_stopButton_clicked()
 {
     mediaPlayer->stop();
+
 }
 
 void MainWindow::on_actionAbout_triggered()
@@ -282,7 +289,7 @@ void MainWindow::on_addStationButton_clicked()
     if (!ok4 ) return;
 
     stationsDb.insertStation(name, url, genre, country);
-    stationsList = stationsDb.getFullStationList();
+    stationsList = stationsDb.getFullStationList(StationsDB::OrderByName);
     saveStationsList();
     ui->stationsList->clear();
     populateList(stationsList);
@@ -311,7 +318,7 @@ void MainWindow::on_editStationButton_clicked()
 
     stationsDb.updateStation(currentUrl, name, url, genre, country);
 
-    stationsList = stationsDb.getFullStationList();
+    stationsList = stationsDb.getFullStationList(StationsDB::OrderByName);
     saveStationsList();
     ui->stationsList->clear();
     populateList(stationsList);
@@ -335,7 +342,7 @@ void MainWindow::on_removeStationButton_clicked()
 
         saveStationsList();
 
-        stationsList = stationsDb.getFullStationList();
+        stationsList = stationsDb.getFullStationList(StationsDB::OrderByName);
         saveStationsList();
         ui->stationsList->clear();
         populateList(stationsList);
@@ -355,7 +362,7 @@ void MainWindow::populateList(QStringList list)
 
         //item->setTextAlignment(Qt::AlignCenter);
     }
-    ui->stationsList->sortItems();
+    //ui->stationsList->sortItems();
 }
 
 void MainWindow::on_stationsList_itemClicked(QListWidgetItem *item)
@@ -436,9 +443,20 @@ void MainWindow::on_actionAbout_Qt_triggered()
 void MainWindow::on_stationsList_customContextMenuRequested(const QPoint &pos)
 {
     QMenu menu(this);
-    menu.addAction(ui->actionDoNotFilter);
-    menu.addAction(ui->actionFilterListByGenre);
-    menu.addAction(ui->actionFilterListByCountry);
+    QMenu menuDoNotFilter(tr("DoNotFilter"), this);
+    QMenu menuFilterList(tr("FilterList"), this);
+    QMenu menuFavouritesManagement(tr("ManageFavourites"), this);
+    menu.addMenu(&menuDoNotFilter);
+    menuDoNotFilter.addAction(ui->actionDoNotFilterOrderByName);
+    menuDoNotFilter.addAction(ui->actionDoNotFilterOrderByGenre);
+    menuDoNotFilter.addAction(ui->actionDoNotFilterOrderByCountry);
+    menu.addAction(ui->actionGetFavouriteList);
+    menu.addMenu(&menuFilterList);
+    menuFilterList.addAction(ui->actionFilterListByGenre);
+    menuFilterList.addAction(ui->actionFilterListByCountry);
+    menu.addMenu(&menuFavouritesManagement);
+    menuFavouritesManagement.addAction(ui->actionAddToFavourites);
+    menuFavouritesManagement.addAction(ui->actionDeleteFromFavourites);
     menu.addAction(ui->actionRestoreDefaultList);
     menu.addAction(ui->actionClearList);
     menu.exec(pos);
@@ -474,7 +492,7 @@ void MainWindow::on_actionRestoreDefaultList_triggered()
 
         stationsDb.restoreDefaultDB();
 
-        stationsList = stationsDb.getFullStationList();
+        stationsList = stationsDb.getFullStationList(StationsDB::OrderByName);
 
         saveStationsList();
         populateList(stationsList);
@@ -519,30 +537,23 @@ void MainWindow::on_titleLineEdit_returnPressed()
     updateLyrics();
 }
 
-void MainWindow::on_actionFilterListByGenre_triggered()
-{
-    QStringList genreList = stationsDb.getGenreList();
-    FilterListByDialog dialog(0, genreList, this);
-    connect(&dialog, SIGNAL(choicePicked(int,QString)), this, SLOT(filterList(int,QString)));
-    dialog.exec();
 
-}
 
 void MainWindow::on_actionFilterListByCountry_triggered()
 {
     QStringList countryList = stationsDb.getCountryList();
     FilterListByDialog dialog(1, countryList);
-    connect(&dialog, SIGNAL(choicePicked(int,QString)), this, SLOT(filterList(int,QString)));
+    connect(&dialog, SIGNAL(choicePicked(int,QString,int)), this, SLOT(filterList(int,QString,int)));
     dialog.exec();
 }
 
-void MainWindow::filterList(int type, QString filter)
+void MainWindow::filterList(int type, QString filter, int orderBy)
 {
     qDebug()<<type<<filter;
 
     if ( type == 0 )
     {
-        stationsList = stationsDb.getListFilteredByGenre(filter);
+        stationsList = stationsDb.getListFilteredByGenre(filter, StationsDB::OrderBy(orderBy));
 
         saveStationsList();
 
@@ -551,7 +562,7 @@ void MainWindow::filterList(int type, QString filter)
     }
     else
     {
-        stationsList = stationsDb.getListFilteredByCountry(filter);
+        stationsList = stationsDb.getListFilteredByCountry(filter, StationsDB::OrderBy(orderBy));
 
         saveStationsList();
 
@@ -560,15 +571,6 @@ void MainWindow::filterList(int type, QString filter)
     }
 }
 
-void MainWindow::on_actionDoNotFilter_triggered()
-{
-    stationsList = stationsDb.getFullStationList();
-
-    saveStationsList();
-
-    ui->stationsList->clear();
-    populateList(stationsList);
-}
 
 void MainWindow::connectBluetoothControl()
 {
@@ -618,3 +620,121 @@ void MainWindow::on_actionSettings_triggered()
     SettingsDialog dialog;
     dialog.exec();
 }
+
+int MainWindow::top_application()
+{
+    show();
+    return 0;
+}
+
+void MainWindow::closeEvent(QCloseEvent *event)
+{
+    QSettings settings("InternetRadioPlayer", "Settings");
+    hideWhenClosing = settings.value("hideWhenClosing", true).toBool();
+
+    if ( !hideWhenClosing )
+    {
+        return;
+    }
+
+
+    if ( quitActionPressed )
+    {
+        //Closing app
+    }
+
+    else
+    {
+        //Hiding app
+        hide();
+        event->ignore();
+    }
+}
+
+void MainWindow::on_actionQuit_triggered()
+{
+    quitActionPressed = true;
+    close();
+}
+
+void MainWindow::on_actionDoNotFilterOrderByName_triggered()
+{
+    stationsList = stationsDb.getFullStationList(StationsDB::OrderByName);
+
+    saveStationsList();
+
+    ui->stationsList->clear();
+    populateList(stationsList);
+}
+
+void MainWindow::on_actionDoNotFilterOrderByGenre_triggered()
+{
+    qDebug()<<"Do Not filter, order by genre";
+    stationsList = stationsDb.getFullStationList(StationsDB::OrderByGenre);
+
+    saveStationsList();
+
+    ui->stationsList->clear();
+    populateList(stationsList);
+}
+
+void MainWindow::on_actionDoNotFilterOrderByCountry_triggered()
+{
+    stationsList = stationsDb.getFullStationList(StationsDB::OrderByCountry);
+
+    saveStationsList();
+
+    ui->stationsList->clear();
+    populateList(stationsList);
+}
+
+
+
+
+void MainWindow::on_actionFilterListByGenre_triggered()
+{
+    QStringList genreList = stationsDb.getGenreList();
+    FilterListByDialog dialog(0, genreList, this);
+    connect(&dialog, SIGNAL(choicePicked(int,QString,int)), this, SLOT(filterList(int,QString,int)));
+    dialog.exec();
+
+}
+
+
+
+
+void MainWindow::on_actionAddToFavourites_triggered()
+{
+    int currentIndex = ui->stationsList->currentRow();
+    qDebug()<<"Current Index: "<<currentIndex;
+    if ( currentIndex == -1) return;
+
+    QString url = ui->stationsList->currentItem()->toolTip();
+    stationsDb.setFavourite(url, true);
+
+
+
+}
+
+void MainWindow::on_actionDeleteFromFavourites_triggered()
+{
+    int currentIndex = ui->stationsList->currentRow();
+    qDebug()<<"Current Index: "<<currentIndex;
+    if ( currentIndex == -1) return;
+
+    QString url = ui->stationsList->currentItem()->toolTip();
+    stationsDb.setFavourite(url, false);
+
+}
+
+void MainWindow::on_actionGetFavouriteList_triggered()
+{
+    stationsList = stationsDb.getFavouriteList();
+
+    saveStationsList();
+
+    ui->stationsList->clear();
+    populateList(stationsList);
+}
+
+
