@@ -8,13 +8,15 @@
 class StationsDB
 {
 public:
+    enum OrderBy { OrderByName, OrderByGenre, OrderByCountry };
+
     StationsDB();
 
-    QStringList getFullStationList();
+    QStringList getFullStationList(OrderBy orderBy);
     QStringList getGenreList();
     QStringList getCountryList();
-    QStringList getListFilteredByGenre(QString filter);
-    QStringList getListFilteredByCountry(QString filter);
+    QStringList getListFilteredByGenre(QString filter, OrderBy orderBy);
+    QStringList getListFilteredByCountry(QString filter, OrderBy orderBy);
     void checkDB();
     void clearDB();
     void restoreDefaultDB();
@@ -22,6 +24,8 @@ public:
     void insertStation(QString name, QString url, QString genre, QString country);
     void deleteStation(QString url);
     void updateStation(QString currentUrl, QString name, QString url, QString genre, QString country);
+    void setFavourite(QString url, bool choice);
+    QStringList getFavouriteList();
 
 private:
     QSqlDatabase db;
